==> foundation-ui-components-1.28.0-cx130-1216.1.tgz: package/src/common/autocomplete/NsAutocomplete.tsx <==
import { Autocomplete, AutocompleteRenderInputParams, Popper } from '@mui/material';
import React, { PropsWithChildren, useEffect, useRef, useState } from 'react';

import { LineLoader } from './helper/LineLoader';
import { RecentClearAll } from './helper/RecentClearAll';
import { renderGroupBy, renderGroupName, renderOptionLabel } from './helper/renderGroupName';
import { SeeMoreButton } from './helper/SeeMoreButton';
import { StyledPopper, StyledTextField } from './NsAutocomplete.styled';
import { ComponentBoxProps, NsAutocompleteProps, OptionsProps } from './types.d';

const noop = () => {};
const NsAutocomplete = ({
    id = 'custom_autocomplete_dropdown',
    options,
    OptionsUI,
    loading,
    noOptionsText,
    onInputChange,
    onChange,
    onFocus,
    clear,
    seeMore,
    placeholder,
    className,
    iconStart,
    iconEnd,
    inputValue,
    value,
    isFilterEnabled = true,
    fullWidth,
}: PropsWithChildren<NsAutocompleteProps>) => {
    const [scrollTopPosition, setScrollTopPosition] = useState(0);
    const listboxRef = useRef<HTMLUListElement | null>(null);

    useEffect(() => {
        if (listboxRef.current && options.length > 0) {
            listboxRef.current.scrollTop = scrollTopPosition;
        }
    }, [options, scrollTopPosition]);

    const renderInput = (params: AutocompleteRenderInputParams) => (
        <StyledTextField
            {...(params as any)}
            placeholder={placeholder}
            InputProps={{
                ...params.InputProps,
                className: 'styled-text-field',
                startAdornment: iconStart,
                endAdornment: iconEnd,
            }}
        />
    );

    const renderOption = (props: ComponentBoxProps, option: OptionsProps) =>
        OptionsUI ? (
            <OptionsUI {...props} option={option} key={props.id} />
        ) : (
            <li {...(props as any)} key={props.id}>
                {option.value}
            </li>
        );

    const renderListBoxComponent = ({ children, ...rest }: ComponentBoxProps) => {
        return (
            <ul
                aria-labelledby={rest['aria-labelledby']}
                onMouseDown={rest.onMouseDown}
                role={rest.role}
                id={rest.id}
                className={rest.className}
                ref={listboxRef}
            >
                <RecentClearAll
                    show={clear?.show ?? false}
                    text={clear?.text ?? 'Clear All'}
                    onClick={clear?.onClear ?? noop}
                    testId="autocomplete-clear-id"
                    recentSearchText={clear?.recentSearchText ?? 'Your Recent Searches'}
                />
                {children}
                <SeeMoreButton
                    onSeeMore={seeMore?.onSeeMore}
                    show={seeMore?.show}
                    text={seeMore?.text}
                    options={options}
                    setScrollTopPosition={setScrollTopPosition}
                    listboxRef={listboxRef}
                />
            </ul>
        );
    };
    return (
        <>
            <LineLoader show={loading ?? false} />
            <Autocomplete
                openOnFocus
                id={id}
                disablePortal
                className={className}
                options={options}
                loading={loading}
                noOptionsText={noOptionsText}
                groupBy={renderGroupBy}
                getOptionLabel={renderOptionLabel}
                renderOption={renderOption as any}
                renderInput={renderInput}
                PopperComponent={fullWidth ? StyledPopper : Popper}
                ListboxComponent={renderListBoxComponent}
                renderGroup={renderGroupName}
                onChange={onChange}
                onInputChange={onInputChange}
                value={value}
                onFocus={onFocus ?? noop}
                inputValue={inputValue}
                filterOptions={
                    isFilterEnabled
                        ? undefined // Use default filtering behavior
                        : (options) => options
                }
                freeSolo
            />
        </>
    );
};

export default NsAutocomplete;

==> foundation-ui-components-1.29.1-cx130-1299.2.tgz: package/src/common/autocomplete/NsAutocomplete.tsx <==
import React, {
    PropsWithChildren,
    useEffect,
    useRef,
    useState,
} from 'react';

import {
    Autocomplete,
    AutocompleteRenderInputParams,
    Popper,
} from '@mui/material';

import { LineLoader } from './helper/LineLoader';
import { RecentClearAll } from './helper/RecentClearAll';
import {
    renderGroupBy,
    renderGroupName,
    renderOptionLabel,
} from './helper/renderGroupName';
import { SeeMoreButton } from './helper/SeeMoreButton';
import {
    StyledPopper,
    StyledTextField,
} from './NsAutocomplete.styled';
import {
    ComponentBoxProps,
    NsAutocompleteProps,
    OptionsProps,
} from './types.d';

const noop = () => {};
const NsAutocomplete = ({
    id = 'custom_autocomplete_dropdown',
    options,
    OptionsUI,
    loading,
    noOptionsText,
    onInputChange,
    onChange,
    onFocus,
    clear,
    seeMore,
    placeholder,
    className,
    iconStart,
    iconEnd,
    inputValue,
    value,
    isFilterEnabled = true,
    fullWidth,
}: PropsWithChildren<NsAutocompleteProps>) => {
    const [scrollTopPosition, setScrollTopPosition] = useState(0);
    const listboxRef = useRef<HTMLUListElement | null>(null);

    useEffect(() => {
        if (listboxRef.current && options.length > 0) {
            listboxRef.current.scrollTop = scrollTopPosition;
        }
    }, [options, scrollTopPosition]);

    const renderInput = (params: AutocompleteRenderInputParams) => (
        <StyledTextField
            {...(params as any)}
            placeholder={placeholder}
            InputProps={{
                ...params.InputProps,
                className: 'styled-text-field',
                startAdornment: iconStart,
                endAdornment: iconEnd,
            }}
        />
    );

    const renderOption = (props: ComponentBoxProps, option: OptionsProps) =>
        OptionsUI ? (
            <OptionsUI {...props} option={option} key={props.id} />
        ) : (
            <li {...(props as any)} key={props.id}>
                {option.value}
            </li>
        );

    const renderListBoxComponent = ({ children, ...rest }: ComponentBoxProps): React.JSX.Element => {
        return (
            <ul
                aria-labelledby={rest['aria-labelledby']}
                onMouseDown={rest.onMouseDown}
                role={rest.role}
                id={rest.id}
                className={rest.className}
                ref={listboxRef}
            >
                <RecentClearAll
                    show={clear?.show ?? false}
                    text={clear?.text ?? 'Clear All'}
                    onClick={clear?.onClear ?? noop}
                    testId="autocomplete-clear-id"
                    recentSearchText={clear?.recentSearchText ?? 'Your Recent Searches'}
                />
                {children}
                <SeeMoreButton
                    onSeeMore={seeMore?.onSeeMore}
                    show={seeMore?.show}
                    text={seeMore?.text}
                    options={options}
                    setScrollTopPosition={setScrollTopPosition}
                    listboxRef={listboxRef}
                />
            </ul>
        );
    };
    return (
        <>
            <LineLoader show={loading ?? false} />
            <Autocomplete
                openOnFocus
                id={id}
                disablePortal
                className={className}
                options={options}
                loading={loading}
                noOptionsText={noOptionsText}
                groupBy={renderGroupBy}
                getOptionLabel={renderOptionLabel}
                renderOption={renderOption as any}
                renderInput={renderInput}
                PopperComponent={fullWidth ? StyledPopper : Popper} // TODO:https://code.tls.nuskin.io/ns-am/content-foundation/nuskin-app/-/jobs/1355817
                ListboxComponent={renderListBoxComponent}
                renderGroup={renderGroupName}
                onChange={onChange}
                onInputChange={onInputChange}
                value={value}
                onFocus={onFocus ?? noop}
                inputValue={inputValue}
                filterOptions={
                    isFilterEnabled
                        ? undefined // Use default filtering behavior
                        : (options) => options
                }
                freeSolo
            />
        </>
    );
};

export default NsAutocomplete;
